pub struct WatchOptions {
pub timeout_duration: Option<Duration>,
pub allow_unhealthy_initial_state: bool,
}Expand description
Options for waiting for a deployment to become healthy.
This struct provides configuration options for waiting for a container to reach a healthy state, including setting a maximum timeout duration.
Examples
use atlas_local::models::WatchOptions;
use std::time::Duration;
let options = WatchOptions::builder()
.timeout_duration(Duration::from_secs(300))
.build();Fields
timeout_duration: Option<Duration>Maximum duration to wait for the deployment to become healthy.
allow_unhealthy_initial_state: boolIndicates that the initial state of the deployment is allowed to be unhealthy.
Implementations
Sourceimpl WatchOptions
impl WatchOptions
Sourcepub fn builder() -> WatchOptionsBuilder<((), ())>
pub fn builder() -> WatchOptionsBuilder<((), ())>
Create a builder for building WatchOptions.
On the builder, call .timeout_duration(...)(optional), .allow_unhealthy_initial_state(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of WatchOptions.