pub struct LogsOptions {
pub stdout: bool,
pub stderr: bool,
pub since: Option<DateTime<Utc>>,
pub until: Option<DateTime<Utc>>,
pub timestamps: bool,
pub tail: Option<Tail>,
}Expand description
Options for retrieving logs from a container.
This struct provides configuration options for fetching container logs, including filtering by stream type (stdout/stderr), limiting the number of lines, and adding timestamps.
Examples
use atlas_local::models::{LogsOptions, Tail};
let options = LogsOptions::builder()
.stdout(true)
.stderr(true)
.tail(Tail::Number(100))
.timestamps(true)
.build();Fields
stdout: boolReturn logs from stdout
stderr: boolReturn logs from stderr
since: Option<DateTime<Utc>>Return logs from the given timestamp
until: Option<DateTime<Utc>>Return logs before the given timestamp
timestamps: boolAdd timestamps to every log line
tail: Option<Tail>Return this number of lines at the tail of the logs
Implementations
Sourceimpl LogsOptions
impl LogsOptions
Sourcepub fn builder() -> LogsOptionsBuilder<((), (), (), (), (), ())>
pub fn builder() -> LogsOptionsBuilder<((), (), (), (), (), ())>
Create a builder for building LogsOptions.
On the builder, call .stdout(...)(optional), .stderr(...)(optional), .since(...)(optional), .until(...)(optional), .timestamps(...)(optional), .tail(...)(optional) to set the values of the fields.
Finally, call .build() to create the instance of LogsOptions.